Core - momapy

Skip to content

# Core

## `` momapy.sbml.core

Classes for SBML maps

Classes:

Name | Description
--- | ---
`BQBiol` | Class for http://biomodels.net/biology-qualifiers/ qualifiers
`BQModel` | Class for http://biomodels.net/model-qualifiers/ qualifiers
`BiomodelQualifier` | Abstract class for http://biomodels.net/ qualifiers
`Compartment` | Compartment(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, outside: Optional[ForwardRef('Compartment', module='momapy.sbml.core')] = None)
`Model` | Model(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, compartments: frozenset[momapy.sbml.core.Compartment] = , species: frozenset[momapy.sbml.core.Species] = , reactions: frozenset[momapy.sbml.core.Reaction] = )
`ModifierSpeciesReference` | ModifierSpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species)
`RDFAnnotation` | RDFAnnotation(*, id_: str = , qualifier: momapy.sbml.core.BiomodelQualifier, resources: frozenset[str] = )
`Reaction` | Reaction(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, reversible: bool, compartment: momapy.sbml.core.Compartment | None = None, reactants: frozenset[momapy.sbml.core.SpeciesReference] = , products: frozenset[momapy.sbml.core.SpeciesReference] = , modifiers: frozenset[momapy.sbml.core.ModifierSpeciesReference] = )
`SBML` | SBML(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, xmlns: str = 'http://www.sbml.org/sbml/level3/version2/core', level: int = 3, version: int = 2, model: momapy.sbml.core.Model | None = None)
`SBOTerm` | SBOTerm(*, id_: str = )
`SBase` | SBase(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None)
`SimpleSpeciesReference` | SimpleSpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species)
`Species` | Species(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, compartment: momapy.sbml.core.Compartment | None = None)
`SpeciesReference` | SpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species, stoichiometry: int | None = None)

### `` BQBiol

Bases: `BiomodelQualifier`

Class for http://biomodels.net/biology-qualifiers/ qualifiers

### `` BQModel

Bases: `BiomodelQualifier`

Class for http://biomodels.net/model-qualifiers/ qualifiers

### `` BiomodelQualifier

Bases: `Enum`

Abstract class for http://biomodels.net/ qualifiers

### `` Compartment `dataclass`

    Compartment(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        outside: Optional[
            ForwardRef(Compartment, module=core)
        ] = None,
    )

Bases: `SBase`

Compartment(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, outside: Optional[ForwardRef('Compartment', module='momapy.sbml.core')] = None)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'8362e4bd-22e0-4968-8e77-2f91616b974b'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`outside` | `ForwardRef(Compartment, module=core) | None` |  | `None`

### `` Model `dataclass`

    Model(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        compartments: frozenset[Compartment] = frozenset(),
        species: frozenset[Species] = frozenset(),
        reactions: frozenset[Reaction] = frozenset(),
    )

Bases: `SBase`, `Model`

Model(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, compartments: frozenset[momapy.sbml.core.Compartment] = , species: frozenset[momapy.sbml.core.Species] = , reactions: frozenset[momapy.sbml.core.Reaction] = )

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'7af0ea73-488f-4437-a92d-b497bc0ac439'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`compartments` | `frozenset[Compartment]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`
`species` | `frozenset[Species]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`
`reactions` | `frozenset[Reaction]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`

### `` ModifierSpeciesReference `dataclass`

    ModifierSpeciesReference(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        referred_species: Species,
    )

Bases: `SimpleSpeciesReference`

ModifierSpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'8a925aaf-ca1a-4b49-a0bf-685443af201a'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`referred_species` | `Species` |  | required

### `` RDFAnnotation `dataclass`

    RDFAnnotation(
        *,
        id_: str = make_uuid4_as_str(),
        qualifier: BiomodelQualifier,
        resources: frozenset[str] = frozenset(),
    )

Bases: `ModelElement`

RDFAnnotation(*, id_: str = , qualifier: momapy.sbml.core.BiomodelQualifier, resources: frozenset[str] = )

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'3cf168d2-1231-472c-8dcd-7b0fabbfed68'`
`qualifier` | `BiomodelQualifier` |  | required
`resources` | `frozenset[str]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`

### `` Reaction `dataclass`

    Reaction(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        reversible: bool,
        compartment: Compartment | None = None,
        reactants: frozenset[SpeciesReference] = frozenset(),
        products: frozenset[SpeciesReference] = frozenset(),
        modifiers: frozenset[
            ModifierSpeciesReference
        ] = frozenset(),
    )

Bases: `SBase`

Reaction(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, reversible: bool, compartment: momapy.sbml.core.Compartment | None = None, reactants: frozenset[momapy.sbml.core.SpeciesReference] = , products: frozenset[momapy.sbml.core.SpeciesReference] = , modifiers: frozenset[momapy.sbml.core.ModifierSpeciesReference] = )

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'a8fe1017-287e-4467-b985-8ef266925787'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`reversible` | `bool` |  | required
`compartment` | `Compartment | None` |  | `None`
`reactants` | `frozenset[SpeciesReference]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`
`products` | `frozenset[SpeciesReference]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`
`modifiers` | `frozenset[ModifierSpeciesReference]` | frozenset() -> empty frozenset object frozenset(iterable) -> frozenset object Build an immutable unordered collection of unique elements. | `<class 'frozenset'>`

### `` SBML `dataclass`

    SBML(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        xmlns: str = "http://www.sbml.org/sbml/level3/version2/core",
        level: int = 3,
        version: int = 2,
        model: Model | None = None,
    )

Bases: `SBase`

SBML(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, xmlns: str = 'http://www.sbml.org/sbml/level3/version2/core', level: int = 3, version: int = 2, model: momapy.sbml.core.Model | None = None)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'9a33dd87-1bc8-488a-8d19-6131f1eb52c9'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`xmlns` | `str` |  | `'http://www.sbml.org/sbml/level3/version2/core'`
`level` | `int` |  | `3`
`version` | `int` |  | `2`
`model` | `Model | None` |  | `None`

### `` SBOTerm `dataclass`

    SBOTerm(*, id_: str = make_uuid4_as_str())

Bases: `ModelElement`

SBOTerm(*, id_: str = )

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'8a8751d0-57cf-4281-89ae-ddc70f2107f1'`

### `` SBase `dataclass`

    SBase(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
    )

Bases: `ModelElement`

SBase(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'3a9f5651-8d82-48a8-92f2-8840418e8d0a'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`

### `` SimpleSpeciesReference `dataclass`

    SimpleSpeciesReference(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        referred_species: Species,
    )

Bases: `SBase`

SimpleSpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'f8d0bbfd-fa01-4ac9-bc53-14e7a82aeadc'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`referred_species` | `Species` |  | required

### `` Species `dataclass`

    Species(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        compartment: Compartment | None = None,
    )

Bases: `SBase`

Species(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, compartment: momapy.sbml.core.Compartment | None = None)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'70b0db6e-828b-4be3-81a8-19b03817d08e'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`compartment` | `Compartment | None` |  | `None`

### `` SpeciesReference `dataclass`

    SpeciesReference(
        *,
        id_: str = make_uuid4_as_str(),
        name: str | None = None,
        sbo_term: SBOTerm | None = None,
        metaid: str | None = None,
        referred_species: Species,
        stoichiometry: int | None = None,
    )

Bases: `SimpleSpeciesReference`

SpeciesReference(*, id_: str = , name: str | None = None, sbo_term: momapy.sbml.core.SBOTerm | None = None, metaid: str | None = None, referred_species: momapy.sbml.core.Species, stoichiometry: int | None = None)

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`id_` | `str` | The id of the map element. This id is purely for the user to keep track of the element, it does not need to be unique and is not part of the identity of the element, i.e., it is not considered when testing for equality between two map elements or when hashing the map element | `'60868847-7171-48cf-a6c1-4859841c24af'`
`name` | `str | None` |  | `None`
`sbo_term` | `SBOTerm | None` |  | `None`
`metaid` | `str | None` |  | `None`
`referred_species` | `Species` |  | required
`stoichiometry` | `int | None` |  | `None`